@@ -113,7 +113,7 @@ unmix <- function(x, pure, alpha, shift, power=1, format="matrix", quiet=FALSE)
   }
 
   mix <- do.call(rbind, res)
-  mix <- mix / rowSums(mix)
+  mix <- mix / MatrixGenerics::rowSums(mix)
   colnames(mix) <- colnames(pure)
   rownames(mix) <- colnames(x)
 
@@ -137,6 +137,9 @@ unmix <- function(x, pure, alpha, shift, power=1, format="matrix", quiet=FALSE)
 #' of a grouping factor \code{groupby}. The purpose of this function
 #' is to sum up read counts from technical replicates to create an object
 #' with a single column of read counts for each sample.
+#' This function will issue a warning if there are other assays other than
+#' \code{"counts"}, see details below in 'Value'.
+#'
 #' Note: by "technical replicates", we mean multiple sequencing runs of the same
 #' library, in constrast to "biological replicates" in which multiple
 #' libraries are prepared from separate biological units.
@@ -154,9 +157,12 @@ unmix <- function(x, pure, alpha, shift, power=1, format="matrix", quiet=FALSE)
 #' using the levels of the grouping factor
 #'
 #' @return the \code{object} with as many columns as levels in \code{groupby}.
-#' This object has assay/count data which is summed from the various
+#' This object has \code{"counts"} data which is summed from the various
 #' columns which are grouped together, and the \code{colData} is subset using
 #' the first column for each group in \code{groupby}.
+#' Other assays are dropped, as it is not unambiguous the correct
+#' form of combination, and a warning is printed if they are present, so
+#' the user is aware they should take care of such assays manually.
 #'
 #' @examples
 #'
@@ -180,10 +186,19 @@ unmix <- function(x, pure, alpha, shift, power=1, format="matrix", quiet=FALSE)
 #' @export
 collapseReplicates <- function(object, groupby, run, renameCols=TRUE) {
   if (!is.factor(groupby)) groupby <- factor(groupby)
+  stopifnot(assayNames(object)[1] == "counts")
+  if (length(assayNames(object)) > 1) {
+    warning("
+
+  Warning! collapseReplicates only sums columns of the 'counts' assay.
+  Other assays are dropped from output, and must be manually combined,
+  as it is not unambiguous how to combine non-count assays.\n")
+    assays(object) <- assays(object)[1]
+  }
   groupby <- droplevels(groupby)
   stopifnot(length(groupby) == ncol(object))
   sp <- split(seq(along=groupby), groupby)
-  countdata <- sapply(sp, function(i) rowSums(assay(object)[,i,drop=FALSE]))
+  countdata <- sapply(sp, function(i) MatrixGenerics::rowSums(assay(object)[,i,drop=FALSE]))
   mode(countdata) <- "integer"
   colsToKeep <- sapply(sp, `[`, 1)
   collapsed <- object[,colsToKeep]
@@ -368,9 +383,9 @@ fpm <- function(object, robust=TRUE) {
   }
   k <- counts(object)
   library.sizes <- if (robust & noAvgTxLen) {
-    sizeFactors(object) * exp(mean(log(colSums(k))))
+    sizeFactors(object) * exp(mean(log(MatrixGenerics::colSums(k))))
   } else {
-    colSums(k)
+    MatrixGenerics::colSums(k)
   }
   1e6 * sweep(k, 2, library.sizes, "/")  
 }
