@@ -114,11 +114,11 @@ dispersionFunction.DESeqDataSet <- function(object) object@dispersionFunction
 #' Accessors for the 'dispersionFunction' slot of a DESeqDataSet object.
 #'
 #' The dispersion function is calculated by \code{\link{estimateDispersions}} and
-#' used by \code{\link{varianceStabilizingTransformation}}.  Parametric dispersion
+#' used by \code{\link{varianceStabilizingTransformation}}. Parametric dispersion
 #' fits store the coefficients of the fit as attributes in this slot.
 #'
-#' Setting this will also overwrite \code{mcols(object)$dispFit} and the estimate
-#' the variance of dispersion residuals, see \code{estimateVar} below.
+#' Using this setter function will also overwrite \code{mcols(object)$dispFit}
+#' and the estimate of the variance of dispersion residuals.
 #'
 #' @rdname dispersionFunction
 #'
@@ -382,7 +382,7 @@ estimateSizeFactors.DESeqDataSet <- function(object, type=c("ratio","poscounts",
     }
     if ("avgTxLength" %in% assayNames(object)) {
       nm <- assays(object)[["avgTxLength"]]
-      nm <- nm / exp(rowMeans(log(nm))) # divide out the geometric mean
+      nm <- nm / exp(MatrixGenerics::rowMeans(log(nm))) # divide out the geometric mean
       normalizationFactors(object) <- estimateNormFactors(counts(object),
                                                           normMatrix=nm,
                                                           locfunc=locfunc,
@@ -521,7 +521,18 @@ this column could have come in during colData import and should be removed.")
 this column could have come in during colData import and should be removed.")
     }
   }
-  if (all(rowSums(counts(object) == counts(object)[,1]) == ncol(object))) {
+
+  # match argument for fitType
+  fitType <- match.arg(fitType, choices=c("parametric","local","mean", "glmGamPoi"))
+  
+  # integer check
+  if (fitType != "glmGamPoi") {
+    if ( !is.integer( counts(object) ) ) {
+      stop("the count data is not in integer mode and fitType is not 'glmGamPoi'")
+    }
+  }
+
+  if (all(MatrixGenerics::rowSums(counts(object) == counts(object)[,1]) == ncol(object))) {
     stop("all genes have equal values for all samples. will not be able to perform differential analysis")
   }
   if (!is.null(dispersions(object))) {
@@ -529,7 +540,6 @@ this column could have come in during colData import and should be removed.")
     mcols(object) <- mcols(object)[,!(mcols(mcols(object))$type %in% c("intermediate","results")),drop=FALSE]
   }
   stopifnot(length(maxit)==1)
-  fitType <- match.arg(fitType, choices=c("parametric","local","mean", "glmGamPoi"))
   dispersionEstimator <- if (fitType == "glmGamPoi") {
     if (!requireNamespace("glmGamPoi", quietly=TRUE)) {
       stop("type='glmGamPoi' requires installing the Bioconductor package 'glmGamPoi'")
