@@ -485,16 +485,16 @@ of length 3 to 'contrast' instead of using 'name'")
       # a new version of greaterAbs suggested by Nikos Ignatiadis
       # which is more powerful and still controls Type I error
       if (!useT) {
-        pfunc <- function(lfc_T, lfc, se) {
+        pfunc_lfc <- function(lfc_T, lfc, se) {
           pnorm(-abs(lfc) + lfc_T, sd=se) + pnorm(-abs(lfc) - lfc_T, sd=se)
         }
       } else {
-        pfunc <- function(lfc_T, lfc, se) {
+        pfunc_lfc <- function(lfc_T, lfc, se) {
           pt((-abs(lfc) + lfc_T)/se, df=df) + pt((-abs(lfc) - lfc_T)/se, df=df)
         }
       }
       newStat <- LFC / SE # just output the Wald stat ...
-      newPvalue <- mapply(pfunc, T, LFC, SE)
+      newPvalue <- mapply(pfunc_lfc, T, LFC, SE)
     } else if (altHypothesis == "greaterAbs2014") {
       # this is the version of greaterAbs that was used 2014-2023
       newStat <- sign(LFC) * pmax((abs(LFC) - T)/SE, 0)
