@@ -8,7 +8,7 @@ test_that("weights work", {
   dds2 <- dds
   w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
   w[1,1] <- 0
-  assays(dds2)[["weights"]] <- w
+  assays(dds2, withDimnames=FALSE)[["weights"]] <- w
   dds2 <- nbinomWaldTest(dds2)
   dds3 <- dds[,-1]
   dds3 <- nbinomWaldTest(dds3)
@@ -46,7 +46,7 @@ test_that("weights work", {
   dds <- makeExampleDESeqDataSet(n=10)
   w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
   w[1,1] <- 0
-  assays(dds)[["weights"]] <- w
+  assays(dds, withDimnames=FALSE)[["weights"]] <- w
   dds <- DESeq(dds, betaPrior=TRUE, quiet=TRUE)
 
   # check weights working for intercept only
@@ -54,7 +54,7 @@ test_that("weights work", {
   design(dds) <- ~1
   suppressWarnings({ dds <- DESeq(dds, quiet=TRUE) })
   dds2 <- dds
-  assays(dds2)[["weights"]] <- w
+  assays(dds2, withDimnames=FALSE)[["weights"]] <- w
   dds2 <- nbinomWaldTest(dds2)
   dds3 <- dds[,-1]
   dds3 <- nbinomWaldTest(dds3)
@@ -73,7 +73,7 @@ test_that("weights work", {
   dds2 <- dds
   w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
   w[1,1] <- 0
-  assays(dds2)[["weights"]] <- w
+  assays(dds2, withDimnames=FALSE)[["weights"]] <- w
   dds2 <- estimateDispersions(dds2)
   dds3 <- dds[,-1]
   dds3 <- estimateDispersions(dds3)
@@ -81,23 +81,6 @@ test_that("weights work", {
   expect_equal(mcols(dds2)[1,"dispGeneEst"],mcols(dds3)[1,"dispGeneEst"],tolerance=1e-3)
   # MAP estimates won't be equal because of different dispersion prior widths...
   expect_true(mcols(dds)[1,"dispMAP"] > mcols(dds2)[1,"dispMAP"])
-
-  # test grid of weights
-  ## set.seed(1)
-  ## dds <- makeExampleDESeqDataSet(n=10, dispMeanRel=function(x) 0.01)
-  ## counts(dds)[1,1] <- 100L
-  ## sizeFactors(dds) <- rep(1,ncol(dds))
-  ## dds <- DESeq(dds, quiet=TRUE, fitType="mean")
-  ## dds2 <- dds
-  ## w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
-  ## lfc <- sapply(seq_len(ncol(dds)-1), function(i) {
-  ##   w[1,1] <- (i-1)/10
-  ##   assays(dds2)[["weights"]] <- w
-  ##   dds2 <- DESeq(dds2, quiet=TRUE, fitType="mean")
-  ##   results(dds2)$log2FoldChange[1]
-  ## })
-  ## plot((seq_len(ncol(dds)-1) - 1)/10, lfc, type="b")
-  ## abline(h=results(dds)$log2FoldChange[1])
   
 })
 
@@ -107,10 +90,34 @@ test_that("weights failing check gives warning, passes them through", {
   dds <- makeExampleDESeqDataSet(n=10)
   w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
   w[1,1:6] <- 0
-  assays(dds)[["weights"]] <- w
+  assays(dds, withDimnames=FALSE)[["weights"]] <- w
   expect_warning(dds <- DESeq(dds))
   expect_true(mcols(dds)$allZero[1])
   expect_true(mcols(dds)$weightsFail[1])
   res <- results(dds)
   
 })
+
+test_that("weights with and without CR term included", {
+
+  set.seed(1); alpha <- .25
+  dmr <- function(x) alpha
+  dds <- makeExampleDESeqDataSet(n=50, m=100, betaSD=1, interceptMean=10, interceptSD=.5, dispMeanRel=dmr)
+  dds$group <- factor(rep(1:50,2)); design(dds) <- ~0 + group + condition
+  w <- matrix(1, nrow=nrow(dds), ncol=ncol(dds))
+  o <- 35
+  w[,c(1:o, 50 + 1:o)] <- 1e-6
+  assays(dds, withDimnames=FALSE)[["weights"]] <- w
+  counts(dds)[,c(1:o, 50 + 1:o)] <- 1L
+  sizeFactors(dds) <- 1
+  dds <- estimateDispersions(dds, fitType="mean")
+  dds2 <- estimateDispersions(dds, fitType="mean", useCR=FALSE)
+  ## dds3 <- estimateDispersions(dds, fitType="mean", weightThreshold=0)
+  ## par(mfcol=c(3,2), mar=c(4.5,4.5,1,1), cex=1.1)
+  ## for (col in c("dispGeneEst","dispersion")) {
+  ##   plot(mcols(dds)$trueBeta, mcols(dds)[[col]], ylim=c(0,2*alpha));abline(h=alpha,col="blue")
+  ##   plot(mcols(dds2)$trueBeta, mcols(dds2)[[col]], ylim=c(0,2*alpha));abline(h=alpha,col="blue")
+  ##   plot(mcols(dds3)$trueBeta, mcols(dds3)[[col]], ylim=c(0,10));abline(h=alpha,col="blue")
+  ## }
+  
+})
